@@ -10,7 +10,7 @@ import graphviz
 import matplotlib.patches as patches
 import matplotlib.pyplot as plt
 from colour import Color, rgb2hex
-from graphviz.backend import run, view
+import graphviz
 from sklearn import tree
 from typing import Mapping, List, Tuple
 from numbers import Number
@@ -45,7 +45,7 @@ class DTreeViz:
 
     def view(self):
         svgfilename = self.save_svg()
-        view(svgfilename)
+        graphviz.backend.view(svgfilename)
 
     def save_svg(self):
         """Saves the current object as SVG file in the tmp directory and returns the filename"""
@@ -76,7 +76,10 @@ class DTreeViz:
         # Gen .svg file from .dot but output .svg has image refs to other files
         cmd = ["dot", f"-T{format}", "-o", filename, dotfilename]
         # print(' '.join(cmd))
-        run(cmd, capture_output=True, check=True, quiet=False)
+        if graphviz.__version__ <= '0.17':
+            graphviz.backend.run(cmd, capture_output=True, check=True, quiet=False)
+        else:
+            graphviz.backend.execute.run_check(cmd, capture_output=True, check=True, quiet=False)
 
         if filename.endswith(".svg"):
             # now merge in referenced SVG images to make all-in-one file
@@ -376,7 +379,7 @@ def ctreeviz_univar(tree_model,
             ax.add_patch(rect)
 
     if 'legend' in show:
-        add_classifier_legend(ax, shadow_tree.class_names, class_values, color_map, shadow_tree.target_name, colors)
+        add_classifier_legend(ax, shadow_tree.class_names, class_values, color_map, shadow_tree.target_name, colors, fontname=fontname)
 
     if 'title' in show:
         accur = shadow_tree.get_score()
@@ -442,7 +445,7 @@ def ctreeviz_bivar(tree_model,
     ax.spines['bottom'].set_linewidth(.3)
 
     if 'legend' in show:
-        add_classifier_legend(ax, shadow_tree.class_names, class_values, color_map, shadow_tree.target_name, colors)
+        add_classifier_legend(ax, shadow_tree.class_names, class_values, color_map, shadow_tree.target_name, colors, fontname=fontname)
 
     if 'title' in show:
         accur = shadow_tree.get_score()
@@ -475,8 +478,8 @@ def add_classifier_legend(ax, class_names, class_values, facecolors, target_name
 
     leg.get_frame().set_linewidth(.5)
     leg.get_title().set_color(colors['legend_title'])
-    # leg.get_title().set_fontsize(fontsize)
-    # leg.get_title().set_fontname(fontname)
+    leg.get_title().set_fontsize(fontsize)
+    leg.get_title().set_fontname(fontname)
     # leg.get_title().set_fontweight('bold')
     for text in leg.get_texts():
         text.set_color(colors['text'])
@@ -502,6 +505,7 @@ def dtreeviz(tree_model,
              X: np.ndarray = None,
              max_X_features_LR: int = 10,
              max_X_features_TD: int = 20,
+             depth_range_to_display: tuple = None,
              label_fontsize: int = 12,
              ticks_fontsize: int = 8,
              fontname: str = "Arial",
@@ -528,7 +532,7 @@ def dtreeviz(tree_model,
     :param tree_model: A DecisionTreeRegressor or DecisionTreeClassifier that has been
                        fit to X_train, y_data.
     :param X_train: A data frame or 2-D matrix of feature vectors used to train the model.
-    :param y_data: A pandas Series or 1-D vector with target values or classes.
+    :param y_data: A pandas Series or 1-D vector with target or classes values. These values should be numeric types.
     :param feature_names: A list of the feature names.
     :param target_name: The name of the target variable.
     :param class_names: [For classifiers] A dictionary or list of strings mapping class
@@ -563,6 +567,7 @@ def dtreeviz(tree_model,
                             display only those features
                            used to guide X vector down tree. Helps when len(X) is large.
                            Default is 25.
+    :param depth_range_to_display: range of depth levels to be displayed. The range values are inclusive
     :param title: An optional title placed at the top of the tree.
     :param title_fontsize: Size of the text for the title.
     :param scale: Default is 1.0. Scale the width, height of the overall SVG preserving aspect ratio
@@ -767,7 +772,7 @@ def dtreeviz(tree_model,
     if shadow_tree.is_classifier():
         class_values = shadow_tree.classes()
         color_map = {v: color_values[i] for i, v in enumerate(class_values)}
-        draw_legend(shadow_tree, shadow_tree.target_name, f"{tmp}/legend_{os.getpid()}.svg", colors=colors)
+        draw_legend(shadow_tree, shadow_tree.target_name, f"{tmp}/legend_{os.getpid()}.svg", colors=colors, fontname=fontname)
 
     X_data = shadow_tree.x_data
     y_data = shadow_tree.y_data
@@ -792,6 +797,9 @@ def dtreeviz(tree_model,
 
     internal = []
     for node in get_internal_nodes():
+        if depth_range_to_display is not None:
+            if node.level not in range(depth_range_to_display[0], depth_range_to_display[1] + 1):
+                continue
         if fancy:
             if shadow_tree.is_classifier():
                 class_split_viz(node, X_data, y_data,
@@ -827,10 +835,14 @@ def dtreeviz(tree_model,
 
     leaves = []
     for node in get_leaves():
+        if depth_range_to_display is not None:
+            if node.level not in range(depth_range_to_display[0], depth_range_to_display[1] + 1):
+                continue
         if shadow_tree.is_classifier():
             class_leaf_viz(node, colors=color_values,
                            filename=f"{tmp}/leaf{node.id}_{os.getpid()}.svg",
-                           graph_colors=colors)
+                           graph_colors=colors,
+                           fontname=fontname)
             leaves.append(class_leaf_node(node))
         else:
             # for now, always gen leaf
@@ -859,6 +871,9 @@ def dtreeviz(tree_model,
     edges = []
     # non leaf edges with > and <=
     for node in get_internal_nodes():
+        if depth_range_to_display is not None:
+            if node.level not in range(depth_range_to_display[0], depth_range_to_display[1]):
+                continue
         nname = node_name(node)
         if node.left.isleaf():
             left_node_name = 'leaf%d' % node.left.id
@@ -1067,7 +1082,8 @@ def class_split_viz(node: ShadowDecTreeNode,
 def class_leaf_viz(node: ShadowDecTreeNode,
                    colors: List[str],
                    filename: str,
-                   graph_colors=None):
+                   graph_colors=None,
+                   fontname: str = "Arial"):
     graph_colors = adjust_colors(graph_colors)
     # size = prop_size(node.nsamples(), counts=node.shadow_tree.leaf_sample_counts(),
     #                  output_range=(.2, 1.5))
@@ -1084,7 +1100,7 @@ def class_leaf_viz(node: ShadowDecTreeNode,
     counts = node.class_counts()
     prediction = node.prediction_name()
     draw_piechart(counts, size=size, colors=colors, filename=filename, label=f"n={nsamples}\n{prediction}",
-                  graph_colors=graph_colors)
+                  graph_colors=graph_colors, fontname=fontname)
 
 
 def regr_split_viz(node: ShadowDecTreeNode,
@@ -1240,7 +1256,7 @@ def regr_leaf_viz(node: ShadowDecTreeNode,
         plt.close()
 
 
-def draw_legend(shadow_tree, target_name, filename, colors=None):
+def draw_legend(shadow_tree, target_name, filename, colors=None, fontname="Arial"):
     colors = adjust_colors(colors)
     n_classes = shadow_tree.nclasses()
     class_values = shadow_tree.classes()
@@ -1272,6 +1288,7 @@ def draw_legend(shadow_tree, target_name, filename, colors=None):
     for text in leg.get_texts():
         text.set_color(colors['text'])
         text.set_fontsize(10)
+        text.set_fontname(fontname)
 
     ax.set_xlim(0, 20)
     ax.set_ylim(0, 10)
